#region Copyright Syncfusion Inc. 2001 - 2008
//
//  Copyright Syncfusion Inc. 2001 - 2008. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion
using Syncfusion.Web.UI.WebControls.Shared;
using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Syncfusion.Web.UI.WebControls.Grid.Grouping;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Web.UI.WebControls.Grid.Grouping.Common;

public partial class HierarchyInCode : System.Web.UI.Page
{
    protected void Page_Init(object sender, EventArgs e)
    {
        this.GridGroupingControl2.DataSource = GetChildTable();
        this.GridGroupingControl2.DataSourceCachingMode = DataSourceCachingMode.ViewState;
    }
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            DataTable parentTable = GetParentTable();
           
            DataTable childTable = this.GridGroupingControl2.DataSource as DataTable;
            DataTable grandChildTable = GetGrandChildTable();

            // Manually specify relations in grouping engine. The DataSet does not need to have any DataRelations.
            // This is the same approach that should be used if you want to set up relation ships
            // between independent IList.
            GridRelationDescriptor parentToChildRelationDescriptor = new GridRelationDescriptor();
            parentToChildRelationDescriptor.ChildTableName = "MyChildTable";    // same as SourceListSetEntry.Name for childTable (see below)
            parentToChildRelationDescriptor.RelationKind = RelationKind.RelatedMasterDetails;
            parentToChildRelationDescriptor.RelationKeys.Add("parentID", "ParentID");

            // Add relation to ParentTable 
            GridGroupingControl1.TableDescriptor.Relations.Add(parentToChildRelationDescriptor);

            GridRelationDescriptor childToGrandChildRelationDescriptor = new GridRelationDescriptor();
            childToGrandChildRelationDescriptor.ChildTableName = "MyGrandChildTable";  // same as SourceListSetEntry.Name for grandChhildTable (see below)
            childToGrandChildRelationDescriptor.RelationKind = RelationKind.RelatedMasterDetails;
            childToGrandChildRelationDescriptor.RelationKeys.Add("childID", "ChildID");

            // Add relation to ChildTable 
            parentToChildRelationDescriptor.ChildTableDescriptor.Relations.Add(childToGrandChildRelationDescriptor);

            // Register any DataTable/IList with SourceListSet, so that RelationDescriptor can resolve the name
            this.GridGroupingControl1.Engine.SourceListSet.Add("MyParentTable", parentTable);
            this.GridGroupingControl1.Engine.SourceListSet.Add("MyChildTable", childTable);
            this.GridGroupingControl1.Engine.SourceListSet.Add("MyGrandChildTable", grandChildTable);

            this.GridGroupingControl1.DataMember = "DefaultView";
            this.GridGroupingControl1.DataSource = parentTable;
            this.GridGroupingControl1.DataSourceCachingMode = DataSourceCachingMode.ViewState;
       
        }
        if (!CheckBox1.Checked)
            ScriptManager1.RegisterPostBackControl(GridGroupingControl1);
        this.GridGroupingControl1.RecordCollapsed += new RecordEventHandler(GridGroupingControl1_RecordCollapsed);
       
    }

    void GridGroupingControl1_RecordCollapsed(object sender, RecordEventArgs e)
    {
        //throw new NotImplementedException();
        this.GridGroupingControl2.Visible = false;
    }
    private int numberParentRows = 5;
    private int numberChildRows = 20;
   
    private int numberGrandChildRows = 50;
    private DataTable GetParentTable()
    {
        DataTable dt = new DataTable("ParentTable");
        dt.Columns.Add(new DataColumn("parentID")); //lower case p
        dt.Columns.Add(new DataColumn("ParentName"));
        dt.Columns.Add(new DataColumn("ParentDec"));

        for (int i = 0; i < numberParentRows; i++)
        {
            DataRow dr = dt.NewRow();
            dr[0] = i;//.ToString();
            dr[1] = string.Format("parentName{0}", i);
            dr[2] = string.Format("parentName{0}", i);
            dt.Rows.Add(dr);
        }

        return dt;
    }

    private DataTable GetChildTable()
    {
        DataTable dt = new DataTable("ChildTable");
        dt.Columns.Add(new DataColumn("childID")); //lower case c
        dt.Columns.Add(new DataColumn("Name"));
        dt.Columns.Add(new DataColumn("ParentID")); //upper case P

        for (int i = 0; i < numberChildRows; i++)
        {
            DataRow dr = dt.NewRow();
            dr[0] = i.ToString();
            dr[1] = string.Format("ChildName{0}", i);
            dr[2] = (i % numberParentRows).ToString();
            dt.Rows.Add(dr);
        }

        return dt;
    }

    private DataTable GetGrandChildTable()
    {
        DataTable dt = new DataTable("GrandChildTable");
        dt.Columns.Add(new DataColumn("GrandChildID"));
        dt.Columns.Add(new DataColumn("Name"));
        dt.Columns.Add(new DataColumn("ChildID")); //upper case C


        for (int i = 0; i < numberGrandChildRows; i++)
        {
            DataRow dr = dt.NewRow();
            dr[0] = i.ToString();
            dr[1] = string.Format("GrandChildName{0}", i);
            dr[2] = (i % numberChildRows).ToString();
            dt.Rows.Add(dr);
        }
        return dt;
    }
    protected void GridGroupingControl1_RecordExpanded(object sender, RecordEventArgs e)
    {
        foreach (GridNestedTable nt in e.Record.NestedTables)
        {
            //Set AllowNew property for the nested tables 
            nt.ChildTable.ParentTableDescriptor.AllowNew = false;
        }
        this.GridGroupingControl2.Visible = true;
    }
}
